@@ -35,6 +35,8 @@ import urlparse
 import pkg_resources
 import zc.buildout
 
+from slapos.recipe.librecipe import shlex
+
 class GenericBaseRecipe(object):
   """Boilerplate class for all Buildout recipes providing helpful methods like
      creating configuration file, creating wrappers, generating passwords, etc.
@@ -107,6 +109,28 @@ class GenericBaseRecipe(object):
       path, arguments=arguments)[0]
     return script
 
+  def createWrapper(self, name, command, parameters):
+    """
+    Creates a very simple (one command) shell script for process replacement.
+    Takes care of quoting.
+    """
+
+    q = shlex.quote
+    lines = [
+            '#!/bin/sh',
+            'exec %s' % shlex.quote(command)
+            ]
+
+    for param in parameters:
+      if len(lines[-1]) < 30:
+        lines[-1] += ' ' + shlex.quote(param)
+      else:
+        lines[-1] += ' \\'
+        lines.append('\t' + shlex.quote(param))
+
+    content = '\n'.join(lines) + '\n'
+    return self.createFile(name, content, 0700)
+
   def createDirectory(self, parent, name, mode=0700):
     path = os.path.join(parent, name)
     if not os.path.exists(path):
